### Contribution of Users in Chat by Hour
I splitted a day into 8 equal parts and extracted statistics of activity ( mine & others too ) for each of those timespans, to learn when users are more active. And no doubt result was interesting _( atleast for Group Chat :wink: )_.

- 00:00:00 - 02:59:59
- 03:00:00 - 05:59:59
- 06:00:00 - 08:59:59
- 09:00:00 - 11:59:59
- 12:00:00 - 14:59:59
- 15:00:00 - 17:59:59
- 18:00:00 - 20:59:59
- 21:00:00 - 23:59:59

Following Pie charts show how two participants contributed to a Private chat i.e. how much active were they at which time period.

![activityOfParticipantOne](../plots/contributionInPrivateChatOf1ByHour.png)

![activityOfParticipantTwo](../plots/contributionInPrivateChatOf2ByHour.png)

Following Pie charts showing how participants were contributing in a Group Chat.

1.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf1ByHour.png)

2.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf2ByHour.png)

3.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf3ByHour.png)

4.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf4ByHour.png)

5.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf5ByHour.png)

6.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf6ByHour.png)

7.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf7ByHour.png)

8.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf8ByHour.png)

9.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf9ByHour.png)

10.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf10ByHour.png)

11.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf11ByHour.png)

12.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf12ByHour.png)

13.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf13ByHour.png)

14.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf14ByHour.png)

15.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf15ByHour.png)

16.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf16ByHour.png)

17.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf17ByHour.png)

18.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf18ByHour.png)

19.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf19ByHour.png)

20.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf20ByHour.png)

21.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf21ByHour.png)

22.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf22ByHour.png)

23.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf23ByHour.png)

24.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf24ByHour.png)

25.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf25ByHour.png)

26.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf26ByHour.png)

27.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf27ByHour.png)

28.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf28ByHour.png)

29.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf29ByHour.png)

30.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf30ByHour.png)

31.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf31ByHour.png)

32.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf32ByHour.png)

33.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf33ByHour.png)

34.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf34ByHour.png)

35.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf35ByHour.png)

36.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf36ByHour.png)

37.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf37ByHour.png)

38.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf38ByHour.png)

39.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf39ByHour.png)

40.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf40ByHour.png)

41.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf41ByHour.png)

42.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf42ByHour.png)

43.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf43ByHour.png)

44.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf44ByHour.png)

45.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf45ByHour.png)
